"use client";
import Image from "next/image";
import { Button } from "@/components/ui/button";
import { DropdownMenu, DropdownMenuContent, DropdownMenuItem, DropdownMenuTrigger } from "@/components/ui/dropdown-menu";
import flag1 from "@/public/images/all-img/flag-1.png";
import flag4 from "@/public/images/all-img/1.png";
import { useState, useEffect } from "react";
import { Check } from "lucide-react";
import { cn } from "@/lib/utils";
import { useLanguage } from '../../../context/LanguageContext';
import { cookiesSetLang, getLangValue } from 'action/cookies'
import { useTranslations } from 'next-intl';

const data = [
  {
    name: "ENG",
    flag: flag1,
    locale: 'en'
  },
  {
    name: "HIN",
    flag: flag4,
    locale: 'hi'
  },
];

const Language = () => {

  const { locale, changeLanguage } = useLanguage();
  const [selected, setSelected] = useState(null);

  useEffect(() => {

    getLanguage();
  }, []);

  const getLanguage = async () => {

    const locale = await getLangValue();
    if (locale == 'hi') {
      setSelected({
        name: "HIN",
        flag: flag4,
        locale: 'hi'
      });
    } else {
      setSelected({
        name: "ENG",
        flag: flag1,
        locale: 'en'
      });
    }

  }

  const handleSelected = async (data) => {
    var lang = 'en';
    if (data.name == 'HIN') {
      lang = 'hi';
    }

    await cookiesSetLang(lang);

    setSelected(data);
  };

  if (!selected) {
    return null;
  }

  return (
    <>
      <DropdownMenu>
        <DropdownMenuTrigger asChild>
          <Button type="button" className="bg-transparent hover:bg-transparent">
            {/* <span className="w-6 h-6 rounded-full mr-1.5">
            <Image
              src={selected.flag}
              alt=""
              className="w-full h-full object-cover rounded-full" />
          </span> */}
            <span className="text-sm " style={{ color: '#000' }}>{selected.name}</span>
          </Button>
        </DropdownMenuTrigger>
        <DropdownMenuContent className="p-2">
          {data.map((item, index) => (
            <DropdownMenuItem
              key={`flag-${index}`}
              className={cn("py-1.5 px-2 cursor-pointer dark:hover:bg-background mb-[2px] last:mb-0", {
                "bg-primary-100": selected && selected.name === item.name
              })}
              onClick={() => handleSelected(item)}
            >
              <span className="w-6 h-6 rounded-full mr-1.5">
                {/* <Image src={item.flag} alt="" className="w-full h-full object-cover rounded-full" /> */}
              </span>
              <span className="text-sm text-default-600">{item.name}</span>
              {selected && selected.name === item.name && (
                <Check className="w-4 h-4 flex-none ml-auto text-default-700" />
              )}
            </DropdownMenuItem>
          ))}
        </DropdownMenuContent>
      </DropdownMenu>
    </>
  );
};

export default Language;
